@@ -1,9 +1,20 @@
 
-// $Id: conv.c,v 1.3 2002/10/30 01:12:20 hio Exp $
+/* $Id: conv.c,v 1.4 2002/10/31 11:08:50 hio Exp $ */
+
+#ifdef _MSC_VER
+#include "EXTERN.h"
+#include "perl.h"
+#include "XSUB.h"
+#include <windows.h>
+#include <winsock.h>
+#define snprintf _snprintf
+#endif
 
 #include "Japanese.h"
 #include <stdio.h>
+#ifndef _MSC_VER
 #include <netinet/in.h>
+#endif
 
 #define DISP_S2U 0
 #define DISP_U2S 0
@@ -52,47 +63,47 @@ xs_sjis_utf8(SV* sv_str)
   {
     const unsigned char* ptr;
     if( src[0]<0x80 )
-    { // ASCII
-      //fprintf(stderr,"ascii: %02x\n",src[0]);
+    { /* ASCII */
+      /*fprintf(stderr,"ascii: %02x\n",src[0]); */
       SV_Buf_append_ch(&result,*src);
       ++src;
       continue;
     }else if( 0xa1<=src[0] && src[0]<=0xdf )
-    { // Ⱦѥ
-      //fprintf(stderr,"kana": %02x\n",src[0]);
+    { /* Ⱦѥ. */
+      /*fprintf(stderr,"kana": %02x\n",src[0]); */
       ptr = (unsigned char*)&g_s2u_table[src[0]];
       ++src;
     }else if( ((0x81<=src[0] && src[0]<=0x9f) || (0xe0<=src[0] && src[0]<=0xfc) )
 	      && (0x40<=src[1] && src[1]<=0xfc && src[1]!=0x7f) )
-    { // 2Хʸ
+    { /* 2Хʸ. */
       register const unsigned short sjis = ntohs(*(unsigned short*)src);
-      //fprintf(stderr,"sjis: %04x\n",sjis);
+      /*fprintf(stderr,"sjis: %04x\n",sjis); */
       ptr = (unsigned char*)&g_s2u_table[sjis];
       src += 2;
     }else
-    { // 
-      //fprintf(stderr,"unknown: %02x\n",src[0]);
+    { /* . */
+      /*fprintf(stderr,"unknown: %02x\n",src[0]); */
       SV_Buf_append_ch(&result,'?');
       ++src;
       continue;
     }
 
-    //fprintf(stderr,"utf8-char : %02x %02x %02x %02x\n",ptr[0],ptr[1],ptr[2],ptr[3]);
+    /*fprintf(stderr,"utf8-char : %02x %02x %02x %02x\n",ptr[0],ptr[1],ptr[2],ptr[3]); */
     if( ptr[3] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",4);
+      /*fprintf(stderr,"utf8-len: [%d]\n",4); */
       SV_Buf_append_ch4(&result,*(int*)ptr);
     }else if( ptr[2] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",3);
+      /*fprintf(stderr,"utf8-len: [%d]\n",3); */
       SV_Buf_append_ch3(&result,*(int*)ptr);
     }else if( ptr[1] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",2);
+      /*fprintf(stderr,"utf8-len: [%d]\n",2); */
       SV_Buf_append_ch2(&result,*(short*)ptr);
     }else if( ptr[0] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",1);
+      /*fprintf(stderr,"utf8-len: [%d]\n",1); */
       SV_Buf_append_ch(&result,*ptr);
     }else
     {
@@ -138,7 +149,7 @@ xs_utf8_sjis(SV* sv_str)
     
     if( *src<=0x7f )
     {
-      // ASCIIϤޤȤɲá
+      /* ASCIIϤޤȤɲá */
       int len = 1;
       while( src+len<src_end && src[len]<=0x7f )
       {
@@ -148,8 +159,8 @@ xs_utf8_sjis(SV* sv_str)
       src+=len;
       continue;
     }
-    // utf8ucsѴ
-    // utf8ΣʸĹå
+    /* utf8ucsѴ */
+    /* utf8ΣʸĹå */
     if( 0xc0<=*src && *src<=0xdf )
     {
       utf8_len = 2;
@@ -171,7 +182,7 @@ xs_utf8_sjis(SV* sv_str)
       ++src;
       continue;
     }
-    // Ĺ­Ƥ뤫å
+    /* Ĺ­Ƥ뤫å */
     if( src+utf8_len-1>=src_end )
     {
       ECHO_U2S((stderr,"  no enough buffer, here is %d, need %d\n",src_end-src,utf8_len));
@@ -179,7 +190,7 @@ xs_utf8_sjis(SV* sv_str)
       ++src;
       continue;
     }
-    // ХܰʹߤʸϰϤǧ
+    /* ХܰʹߤʸϰϤǧ */
     succ = true;
     for( i=1; i<utf8_len; ++i )
     {
@@ -196,7 +207,7 @@ xs_utf8_sjis(SV* sv_str)
       ++src;
       continue;
     }
-    // utf8ucsΥɤ򻻽
+    /* utf8ucsΥɤ򻻽 */
     ECHO_U2S((stderr,"utf8-charlen: [%d]\n",utf8_len));
     switch(utf8_len)
     {
@@ -232,14 +243,14 @@ xs_utf8_sjis(SV* sv_str)
       }
     default:
       {
-        // NOT REACH HERE
+        /* NOT REACH HERE */
 	ECHO_U2S((stderr,"invalid utf8-length: %d\n",utf8_len));
 	ucs = '?';
       }
     }
 
     if( 0x0f0000<=ucs && ucs<=0x0fffff )
-    { // ʸȽ(sjis)
+    { /* ʸȽ(sjis) */
       SV_Buf_append_ch(&result,'?');
       assert(utf8_len>=4);
       src += utf8_len;
@@ -247,18 +258,18 @@ xs_utf8_sjis(SV* sv_str)
     }
 
     if( ucs & ~0xFFFF )
-    { // ucs2ϰϳ (ucs4ϰ)
+    { /* ucs2ϰϳ (ucs4ϰ) */
       SV_Buf_append_entityref(&result,ucs);
       src += utf8_len;
       continue;
     }
     
-    // ucs => sjis
+    /* ucs => sjis */
     ECHO_U2S((stderr,"ucs2 [%04x]\n",ucs));
     ECHO_U2S((stderr,"sjis [%04x]\n",ntohs(g_u2s_table[ucs]) ));
     
     if( g_u2s_table[ucs] || !ucs )
-    { // бʸucs=='\0'λ
+    { /* бʸucs=='\0'λ */
       if( g_u2s_table[ucs] & 0xff00 )
       {
 	SV_Buf_append_ch2(&result,g_u2s_table[ucs]);
@@ -274,7 +285,7 @@ xs_utf8_sjis(SV* sv_str)
       SV_Buf_append_entityref(&result,ucs);
     }
     src += utf8_len;
-    //bin_dump("now",dst_begin,dst-dst_begin);
+    /*bin_dump("now",dst_begin,dst-dst_begin); */
   } /* for */
 
   ON_U2S( bin_dump("out",result.getBegin(),result.getLength()) );
